# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.models.uuid_array import UUIDArray  # noqa: E501
from teralytic.rest import ApiException


class TestUUIDArray(unittest.TestCase):
    """UUIDArray unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUUIDArray(self):
        """Test UUIDArray"""
        # FIXME: construct object with mandatory attributes with example values
        # model = teralytic.models.uuid_array.UUIDArray()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
