# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.readings_api import ReadingsApi  # noqa: E501
from teralytic.rest import ApiException


class TestReadingsApi(unittest.TestCase):
    """ReadingsApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.readings_api.ReadingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_analytics_query(self):
        """Test case for analytics_query

        Query reading anlaytics  # noqa: E501
        """
        pass

    def test_readings_query(self):
        """Test case for readings_query

        Query sensor readings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
