# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.0.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.organization_api import OrganizationApi  # noqa: E501
from teralytic.rest import ApiException


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.organization_api.OrganizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_application_create(self):
        """Test case for application_create

        Create a new organization client with the specified scope  # noqa: E501
        """
        pass

    def test_application_delete(self):
        """Test case for application_delete

        Delete an application api client  # noqa: E501
        """
        pass

    def test_application_list(self):
        """Test case for application_list

        Get organization applications  # noqa: E501
        """
        pass

    def test_field_get(self):
        """Test case for field_get

        List single Field details associated with Field id provided (from set of Fields associated with the account key)  # noqa: E501
        """
        pass

    def test_field_list(self):
        """Test case for field_list

        List all Fields associated with account key  # noqa: E501
        """
        pass

    def test_organization_get(self):
        """Test case for organization_get

        Get a specific organization  # noqa: E501
        """
        pass

    def test_organization_list(self):
        """Test case for organization_list

        List all Organizations  # noqa: E501
        """
        pass

    def test_probe_get(self):
        """Test case for probe_get

        List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)  # noqa: E501
        """
        pass

    def test_probe_list(self):
        """Test case for probe_list

        List all Probes associated with account key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
